@@ -90,6 +90,10 @@ class Average(Operator):
     METHOD = "average"
 
 
+class AverageByTime(Operator):
+    METHOD = "average_time"
+
+
 class Subset(Operator):
     METHOD = "subset"
 
